CREATE TABLE FB_LOCATION (
  ID_FB_LOCATION NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT FB_LOCATION_PK PRIMARY KEY (ID_FB_LOCATION)
);

ALTER TABLE FB_LOCATION
ADD NNLOCATION_ID NUMBER;

CREATE SEQUENCE FB_LOCATION_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE FB_TABLE (
  ID_FB_TABLE NUMBER NOT NULL,
  ID_FB_LOCATION NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  CAPACITY NUMBER,
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT FB_TABLE_PK PRIMARY KEY (ID_FB_TABLE),
  CONSTRAINT FB_TABLE_LOCATION_FK FOREIGN KEY (ID_FB_LOCATION) REFERENCES FB_LOCATION(ID_FB_LOCATION)
);

CREATE INDEX IX_FB_TABLE_ID_FB_LOCATION ON FB_TABLE (ID_FB_LOCATION);

CREATE SEQUENCE FB_TABLE_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_FB_TABLE AS (
SELECT FT.ID_FB_TABLE, FT.ID_FB_LOCATION, FT.DESCRIPTION, FT.CAPACITY, FT.ACTIVE, FL.NNLOCATION_ID AS NNLOCATION_ID, FL.DESCRIPTION AS LOCATION_DESCRIPTION
FROM FB_TABLE FT
LEFT OUTER JOIN FB_LOCATION FL ON FL.ID_FB_LOCATION = FT.ID_FB_LOCATION
);

CREATE TABLE FB_RESERVATION_STATUS (
  ID_FB_RESERVATION_STATUS NUMBER NOT NULL,
  DESCRIPTION VARCHAR2(200 CHAR),
  COLOR VARCHAR2(20 CHAR),
  TEXT_COLOR VARCHAR2(20 CHAR),
  ACTIVE VARCHAR2(1 CHAR),
  CONSTRAINT FB_RESERVATION_STATUS_PK PRIMARY KEY (ID_FB_RESERVATION_STATUS)
);

INSERT INTO FB_RESERVATION_STATUS(ID_FB_RESERVATION_STATUS, DESCRIPTION, ACTIVE) VALUES
(-10, 'Deleted', 'N');

INSERT INTO FB_RESERVATION_STATUS(ID_FB_RESERVATION_STATUS, DESCRIPTION, ACTIVE) VALUES
(-1, 'Cancelled', 'Y');

INSERT INTO FB_RESERVATION_STATUS(ID_FB_RESERVATION_STATUS, DESCRIPTION, ACTIVE) VALUES
(1, 'Open', 'Y');

CREATE SEQUENCE FB_RESERVATION_STATUS_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 20 NOCACHE NOORDER  NOCYCLE;

CREATE TABLE FB_RESERVATION (
  ID_FB_RESERVATION NUMBER NOT NULL,
  ID_FB_TABLE NUMBER,
  ID_LASTNIKA NUMBER,
  ID_STATUS NUMBER,
  DATE_FROM DATE,
  DATE_TO DATE,
  NUMBER_OF_PERSONS NUMBER,
  "COMMENT" VARCHAR2(300 CHAR),
  CONSTRAINT FB_RESERVATION_PK PRIMARY KEY (ID_FB_RESERVATION),
  CONSTRAINT FB_RESERVATION_ID_FB_TABLE_FK FOREIGN KEY (ID_FB_TABLE) REFERENCES FB_TABLE(ID_FB_TABLE),
  CONSTRAINT FB_RESERVATION_ID_LASTNIKA_FK FOREIGN KEY (ID_LASTNIKA) REFERENCES KUPCI(ID),
  CONSTRAINT FB_RESERVATION_ID_STATUS_FK FOREIGN KEY (ID_STATUS) REFERENCES FB_RESERVATION_STATUS(ID_FB_RESERVATION_STATUS)
);

CREATE INDEX IX_FB_RESERVATION_ID_FB_TABLE ON FB_RESERVATION (ID_FB_TABLE);
CREATE INDEX IX_FB_RESERVATION_ID_LASTNIKA ON FB_RESERVATION (ID_LASTNIKA);
CREATE INDEX IX_FB_RESERVATION_ID_STATUS ON FB_RESERVATION (ID_STATUS);

CREATE SEQUENCE FB_RESERVATION_SEQ MINVALUE 1 INCREMENT BY 1 START WITH 1 NOCACHE NOORDER  NOCYCLE;

CREATE OR REPLACE VIEW V_FB_RESERVATION AS (
SELECT FR.ID_FB_RESERVATION, FR.ID_FB_TABLE, FR.ID_LASTNIKA, FR.ID_STATUS, FR.DATE_FROM, FR.DATE_TO, FR.NUMBER_OF_PERSONS, FR."COMMENT",
FT.ID_FB_LOCATION, FT.DESCRIPTION AS TABLE_DESCRIPTION, FT.CAPACITY AS TABLE_CAPACITY, FS.DESCRIPTION AS STATUS_DESCRIPTION, FS.COLOR AS STATUS_COLOR, FS.TEXT_COLOR AS STATUS_TEXT_COLOR,
(CASE WHEN (SELECT VREDNOST FROM S_NASTAVITVE WHERE FILTER = 'MARINA' AND SEKCIJA = 'MARINA' AND NAZIV = 'ChangeFirstLastName') = '1' THEN (KUP.IME || ' ' || KUP.PRIIMEK) ELSE (KUP.PRIIMEK || ' ' || KUP.IME) END) AS OWNER
FROM FB_RESERVATION FR
LEFT OUTER JOIN FB_TABLE FT ON FT.ID_FB_TABLE = FR.ID_FB_TABLE
LEFT OUTER JOIN FB_RESERVATION_STATUS FS ON FS.ID_FB_RESERVATION_STATUS = FR.ID_STATUS
LEFT OUTER JOIN KUPCI KUP ON KUP.ID = FR.ID_LASTNIKA
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1560, SYSDATE, '5.5', 1480, 'Food and beverage')
;
